@@ -1,56 +1,10 @@
 #!/usr/bin/python3
 
-from os import path
-import socket
 import httpx
-import random
-import bs4 
-import time
-import sys
-import re
-import os
 from libraccoon.utils.utils import get_user_agent
-import socket 
 from libraccoon.utils.utils import get_asn
 from libraccoon.utils.utils import get_ips
 
-class Request():
-    def dns(target):
-        try:
-            return socket.gethostbyname_ex(target)
-        except:
-            return []
-
-    def https(url, ua):
-        headers = {"user-agent": ua}
-        try:
-            resp = requests.get("https://"+url, headers=headers, timeout=5)
-            return [resp.status_code, resp.headers["Server"] if "Server" in resp.headers.keys() else ""]
-        except:
-            return []
-    def http(url, ua):
-        headers = {"user-agent":ua}
-        try:
-            resp = requests.get("http://"+url, headers=headers, timeout=5)
-            return [resp.status_code, resp.headers["Server"] if "Server" in resp.headers.keys() else ""]
-        except:
-            return []
-
-    def bs4scrape(params):
-        target, url, headers = params
-        resp = requests.get(url, headers=headers, timeout=5)
-        
-        pattern = "http(s)?:\/\/(.*)\.%s" % target
-        subdomains = []
-        if resp.status_code == 200:
-            soup = bs4.BeautifulSoup(resp.text, "html.parser")
-            for item in soup.find_all("a", href=True):
-                if item["href"].startswith("http") and item["href"].find(target) != -1 and item["href"].find("-site:") == -1:
-                    match = re.match(pattern, item["href"])
-                    if match and re.match("^[a-zA-Z0-9-]*$", match.groups()[1]):
-                        subdomains.append(match.groups()[1])
-        return list(dict.fromkeys(subdomains))
-
 class KnockPY(object):
     def __init__(self, domain, wordlist=None, 
                     virustotalapi=None, 
@@ -64,49 +18,35 @@ class KnockPY(object):
         self.discoveryapi = discoveryapi
         self.securitytrail = securitytrail
         self.ua=ua
-        self.timeout = 10
+        self.timeout = 50
+        
         if(not self.ua):
             self.ua = get_user_agent()
-                
-    def local(self):
-        try:
-            wlist = open(filename,'r').read().split("\n")
-        except:
-            ROOT = os.path.abspath(os.path.dirname(__file__))
-            filename = os.path.join(_ROOT, "", filename)
-            wlist = open(filename,'r').read().split("\n")
-        return filter(None, wlist)
     
-    async def google(self):
-        headers = {"user-agent": self.ua}
-        dork = "site:%s -site:www.%s" % (self.domain, self.domain)
-        url = "https://google.com/search?q=%s&start=%s" % (dork, str(5))
-        params = [self.domain, url, headers]
-        
-        subdomains = []
+    async def bufferover_run(self):
         try:
-            subs =  Request.bs4scrape(params)
-            for sub in subs:
-                subdomains.append(sub+"."+self.domain)
-            return subdomains
+            print("Searching using bufferoverrun")
+            
+            url = "https://dns.bufferover.run/dns?q={domain}".format(domain=self.domain)
+            resp = {} 
+            subdomains = []
+            
+            async with httpx.AsyncClient() as client:
+                req = await client.get(url, timeout=self.timeout)
+                resp = req.json()
+                
+            FDNS_A = req.json().get("FDNS_A")
+            for fdns in FDNS_A:
+                if("," in fdns):
+                    sub = fdns.split(",")[-1]
+                    subdomains.append(sub)
+                else:
+                    subdomains.append(fdns)
+            return list(set(subdomains))
+            
         except Exception as e:
-            return subdomains
-
-    async def duckduckgo(self):
-        headers = {"user-agent": self.ua}
-        dork = "site:%s -site:www.%s" % (self.domain, self.domain)
-        url = "https://duckduckgo.com/html/?q=%s" % dork
-        params = [self.domain, url, headers]
-        
-        subdomains = []
-        try:
-            subs =  Request.bs4scrape(params)
-            for sub in subs:
-                subdomains.append(sub+"."+self.domain)
-            return subdomains
-        except Exception as e:
-            return subdomains
-
+            return []
+            
     async def virustotal(self):
         try:
             if not self.virustotalapi: 
@@ -124,7 +64,6 @@ class KnockPY(object):
             return subdomains
             
         except Exception as e:
-            print("virustotalO ERROR ", e)
             return []
             
     async def projectdiscovery(self):
@@ -151,7 +90,7 @@ class KnockPY(object):
                         subdomains.append(subs+"."+subdomain_domain)
                     return subdomains 
             return []
-        except Exception as e:            
+        except Exception as e:
             return []
             
     async def securitytrails(self):
@@ -194,11 +133,14 @@ class KnockPY(object):
         print("project securitytrails")
         subdomains += await self.securitytrails()
         
-        subdomains = list(set(subdomains))
+        print("project bufferover_run")
+        subdomains += await self.bufferover_run()
         
+        subdomains_generator = (sub for sub in list(set(subdomains)))
+                
         if(resolve):
             subdomain_list = []
-            for sub in subdomains:
+            for sub in subdomains_generator:
                 ip = ""
                 
                 ip_results = await get_ips(sub)
@@ -221,14 +163,16 @@ class KnockPY(object):
         
         # If the return should be dictionary
         if(return_dict):
-            subdomain_list = []
-            for sub in subdomains:
-                subdomain_list.append({
+            subdomain = []
+            
+            for sub in subdomains_generator:
+                subdomain.append({
                     "host":self.domain,
                     "subdomain":sub,
-                    "ip":""
+                    "ip":"",
+                    "asn":""
                 })
-            return subdomain_list
+            return subdomain
         
         # If neither resolve or return_dict, return the default
         return subdomains
